🚨Please review the [Troubleshooting](../#troubleshooting) section
before reporting any issue. Don't forget also to check the current issues to
avoid duplicates.

### Subject of the issue
Describe your issue here.

### Your environment
* Operating System (name/version):
* Python version:
* youtube-dl version:
* edx-dl version:

### Steps to reproduce
Tell us how to reproduce this issue. Please provide us the course URL, and the
specific subsection or unit if possible.

### Expected behaviour
Tell us what should happen.

### Actual behaviour
Tell us what happens instead. If the script fails, please copy the *entire*
output of the command or the stacktrace (don't forget to obfuscate your
username and password). If you cannot copy the exception, attach a screenshot.
